function BrightSystemController(platform){

    if(arguments.callee._singletonInstance){
        return arguments.callee._singletonInstance;
    }
    arguments.callee._singletonInstance = this;

    if(typeof(platform) !== "undefined"){
      this.platform = platform;
    }


    this.isARM = false;
  
    this.detection_window = false;
    this.window_showing = true;

    this.busy = false;

    var self = this; self.name = "BrightSystemController"; // MANDATORY
    this.rootDir = "http://127.0.0.1:9090/";
    this.appDir = "./";

    this.systemIsUpdating = false;
    this.internet_connection = false;


    this.tray = false;

    this.dataInfoSystem = null;
    this.sendInfoSystem = false;
    this.superEco = false;
    this.eco = false;
    this.screenshotServer = null;
    this.id_content_now = null;

    this.player_paused_by_user = false;
    this.player_menu_item = null;
    this.SocketConnector = undefined;

    this.sync_master_supported = true;

    this.nodejs_service = null;
    this.ready_callback = false;
    
    this.network_info = {
        ip: "0.0.0.0",
        netmask : "0.0.0.0",
        gateway : "0.0.0.0"
    };
    
    this.init = function(callback){
      self.ready_callback = callback;
      console.log("Node should be up  ....");
      self.SocketConnector = new SocketConnector(self);
      self.nodejs_service = io.connect('http://127.0.0.1:9090',{"transports": ['websocket'], "force new connection":false, "timeout":20000, "reconnection": true, "reconnectionDelay": 20000, "reconnectionDelayMax" : 25000, "reconnectionAttempts" :20});
      self.checkFolders();
      self.checkCoreFile();
    };

    this.checkFolders = function(){
        self.log("Checking folders ...");
        var exists = false;
        for(var route in self.ROUTES){
            if(self.ROUTES[route].isFolder && !self.ROUTES[route].exists){
                self.makeDir(self.ROUTES[route].path);
                self.ROUTES[route].exists = exists;
            }
        }
        self.log("Folders checked ...");
    };
    
    this.checkCoreFile = function(){
        self.log("Checking core ...");
        self.fileExists(self.ROUTES['CORE'].path,function(exists,file_ref){
            self.log("Core checked ...");
            if(exists){
                self.checkConfigFile();
            }else{
                self.createCoreFile();
            }
        });
    };

    this.createCoreFile = function(){
        var xml_data = '<?xml version="1.0" encoding="utf-8" ?><core><config><id>0</id><api_ver>3.0</api_ver><api_url>apilb.admira.com</api_url></config><server url="apilb.admira.com"/></core>';
        self.writeFile(self.ROUTES['CORE'].path,xml_data,function(){
            self.checkConfigFile();
        });
        var style_data = '<?xml version="1.0" encoding="utf-8"?><!DOCTYPE svg PUBLIC "-//W3C//DTD SVG 1.1//EN" "http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd"><svg  xmlns="http://www.w3.org/2000/svg"  version="1.1" id="SVG_1"  x="0px" y="0px" enable-background="new 0 0 100% 100%" style="background-color:#000"><circle cx="98%" cy="98%" r="0.5%" style="stroke: #68983F; fill: #68983F;"><animate id="animation1" attributeName="opacity" from="0" to="1" dur="1s" begin="0s;animation2.end" /><animate id="animation2" attributeName="opacity" from="1" to="0" dur="1s" begin="animation1.end" /></circle></svg>';
        self.writeFile(self.ROUTES['STYLE'].path+"logo.svg",style_data,function(){
           self.log("LOGO File created ! ");
        });

    };

    this.checkConfigFile = function(){
        self.log("Checking config ...");
        self.fileExists(self.ROUTES['CONFIG'].path,function(exists,file_ref){
            self.log("Config checked ...");
            if(exists){
                self.checkDataXmlFile();
            }else{
                self.createConfigFile();
            }
        });
    };

    this.createConfigFile = function(){
        self.log("Creating Config file ...");
        var xml_data = '<config><data file="datos.xml"/><paths multiplayer_delimiter="_" xmls="xmls/" content="content/" temp="temp/" modules="modules/" log="log/" stadistics="stats/"/><params bumper_content="assets/downloading.swf" bumper_duration="56" alwaysontop="1"/></config>';
        self.writeFile(self.ROUTES['CONFIG'].path,xml_data,function(){
            self.log("Config file created ...");
            self.checkDataXmlFile();
        });
    };

    this.checkDataXmlFile = function(){
        self.log("Checking XML file ...");
        var filename = self.getDayOfWeek()+".xml";
        self.fileExists(self.ROUTES['XML'].path+filename,function(exists,file_ref){
            self.log("XML file checked ...");
            if(exists){
                self.ready_callback();
                //self.log("READY");
            }else{
                self.createDataXmlFile();
            }
        });
    };

    this.createDataXmlFile = function(){
        self.log("Creating XML file ...");
        var filename = self.getDayOfWeek()+".xml";
        var xml_data = '<?xml version="1.0"?><admira timestamp="1" version="1.0" status="ok"><archive/><playlist><loop/></playlist><screens /><config volume="100" fullscreen="true" mode="1" always_on_top="true" plv_name="Debug Name" project_name="Debug Project" time="30" plv_id="0" quit_on_click="true" activated="false" domain="" api_key="" live_url="" live_recheck_seconds="" live_send_id=""><resolution x="100" y="100" width="300" height="300" /></config></admira>';
        self.writeFile(self.ROUTES['XML'].path+filename,xml_data,function(){
            self.log("XML file created ...");
            self.ready_callback();
        });
    }

    this.createTrayIcon = function(){
  
    }

    this.togglePlayerMenu = function(){

    }
    this.writeFile = function(filename,value,callback,params){
        self.nodejs_service.emit("request",{'command':'writeFile','filename':filename,'value':value,'callback':true,'params':params},function(ok,filename,params){
          if(typeof(callback) !== "undefined"){
              callback(ok,filename,params);
          }
        });
    };

    this.appendFile = function(filename,value,callback,params){
        self.nodejs_service.emit("request",{'command':'appendFile','filename':filename,'value':value,'callback':true,'params':params},function(ok,filename,params){
          if(typeof(callback) !== "undefined"){
              callback(ok,filename,params);
          }
        });
    };

    this.readFile = function(filename,callback,params){
      self.nodejs_service.emit("request",{'command':'readFile','filename':filename,'callback':true,'params':params},function(data,filename,params){
        if(typeof(callback) !== "undefined"){
            callback(data,filename,params);
        }
      });
      
    };
    
    this.checkSize = function(filename,callback,params){
      self.nodejs_service.emit("request",{'command':'checkSize','filename':filename,'callback':true,'params':params},function(ok,filename,params){
        if(typeof(callback) !== "undefined"){
            callback(ok,filename,params);
        }
      });
    };
    
    this.makeDir = function(path,callback,params){
      self.nodejs_service.emit("request",{'command':'makeDir','path':path,'callback':true,'params':params},function(ok,path,params){
        if(typeof(callback) !== "undefined"){
            callback(ok,path,params);
        }
      });
    };


    this.fileHash = function(filename,callback,params){
      self.nodejs_service.emit("request",{'command':'fileHash','filename':filename,'callback':true,'params':params},function(hash,filename,params){
        if(typeof(callback) !== "undefined"){
            callback(hash,filename,params);
        }
      });
      
    };

    this.fileExists = function(filename,callback,params){
        self.nodejs_service.emit("request",{'command':'fileExists','filename':filename,'callback':true,'params':params},function(ok,filename,params){
          if(typeof(callback) !== "undefined"){
              callback(ok,filename,params);
          }
        });
    };

    this.modificationDate = function(filename,callback,params){
      self.nodejs_service.emit("request",{'command':'modificationDate','filename':filename,'callback':true,'params':params},function(date,filename,params){
        if(typeof(callback) !== "undefined"){
            callback(date,filename,params);
        }
      });
    };

    this.downloadFile = function(url,destFolder,callback,params){
      self.nodejs_service.emit("request",{'command':'downloadFile','url':url,'destFolder':destFolder,'callback':true,'params':params},function(ok,url,params){
        if(typeof(callback) !== "undefined"){
            callback(ok,url,params);
        }
      });
    };

    this.unzipFile = function(filename,destFolder,callback,params){
      self.nodejs_service.emit("request",{'command':'unzipFile','filename':filename,'destFolder':destFolder,'callback':true,'params':params},function(ok,filename,params){
        if(typeof(callback) !== "undefined"){
            callback(ok,filename,params);
        }
      });
    };


    this.readDirectory = function(directory,callback,params){
      self.nodejs_service.emit("request",{'command':'readDirectory','directory':directory,'callback':true,'params':params},function(files,directory,params){
        if(typeof(callback) !== "undefined"){
            callback(files,directory,params);
        }
      });

    };

    this.watchDirectory = function(directory,compare_files,callback,params){
      self.nodejs_service.emit("request",{'command':'watchDirectory','directory':directory,'compate_files':compare_files,'callback':true,'params':params},function(compare_files,changed,params){
        if(typeof(callback) !== "undefined"){
            callback(compare_files,changed,params);
        }
      });
    };

    this.deleteRecursive = function(path){
      // Used By bright-node.js
      /*
        var files = [];
        if(self.fs.existsSync(path)) {
            if(self.fs.lstatSync(path).isDirectory()){
                files = self.fs.readdirSync(path);
                files.forEach(function(file,index){
                    var curPath = path + "/" + file;
                    if(self.fs.lstatSync(curPath).isDirectory()){
                        self.deleteRecursive(curPath);
                    } else { // delete file
                        try{
                          self.fs.unlinkSync(curPath);
                        }catch(e){
                          self.log("could not delete : "+curPath);
                        }
                    }
                });
                try{
                  self.fs.rmdirSync(path);
                }catch(e){
                  self.log("could not delete dir : "+path);
                }
            }else{
              try{
                self.fs.unlinkSync(path);
              }catch(e){
                self.log("could not delete : "+path);
              }
            }
        }
        */
    };

    this.deleteFilesInDir = function(dir,filter,callback,params){
      // Used By bright-node.js
      /*
        self.fs.readdir(dir, function(err,files){
            if(err){
                self.notifyError(self.ERROR['OPERATING_SYSTEM_CONTROLLER']+5,self.name+": Function deleteFilesInDir() failed : error while reading directory  : "+dir);
                if(typeof(callback) !== "undefined"){
                    callback([],dir,params); // Send emtpy array if error
                }
                throw err;
            }
            if(typeof(filter) === "undefined"){filter = "";}
            var deleted_files = [];
            for(var i=0;i<files.length;i++){
                if(filter != ""){
                    var index = files[i].lastIndexOf(filter);
                    if(index >= 0){
                        self.log(files[i]+" contains : "+filter+" delete");
                        self.fs.unlinkSync(self.rootDir+dir+files[i]);
                        deleted_files.push(files[i]);
                    }
                }else{
                    self.log("delete temp dir file : "+self.rootDir+dir+files[i]);
                    self.fs.unlinkSync(self.rootDir+dir+files[i]);
                    deleted_files.push(files[i]);
                }
            }

            if(typeof(callback) !== "undefined"){
                callback(deleted_files,dir,params);
            }
        });
        */
    };

    this.deleteFile = function(filename,callback,params){
        self.nodejs_service.emit("request",{'command':'deleteFile','filename':filename,'callback':true,'params':params},function(ok,filename,params){
          if(typeof(callback) !== "undefined"){
              callback(ok,filename,params);
          }
        });
    };

    this.moveFile = function(source,destination,callback,params){
        self.nodejs_service.emit("request",{'command':'moveFile','source':source,'destination':destination,'callback':true,'params':params},function(ok,filename,params){
          if(typeof(callback) !== "undefined"){
              callback(ok,filename,params);
          }
        });
    };
    
    this.copyFile = function(source,destination,callback,params){
        self.nodejs_service.emit("request",{'command':'copyFile','source':source,'destination':destination,'callback':true,'params':params},function(ok,filename,params){
          if(typeof(callback) !== "undefined"){
              callback(ok,filename,params);
          }
        });

    }

    this.copyRecursiveSync = function(src,dest){
      // Used By bright-node.js
      /*
      try{
        var exists = self.fs.existsSync(src);
        var stats = exists && self.fs.lstatSync(src);
        var isDirectory = exists && stats.isDirectory();
        if(exists && isDirectory){
          if(!self.fs.existsSync(dest)){
            self.fs.mkdirSync(dest);
          }
          self.fs.readdirSync(src).forEach(function(childItemName){
            self.copyRecursiveSync(self.path.join(src, childItemName),self.path.join(dest, childItemName));
          });
        }else{
          self.fs.writeFileSync(dest,self.fs.readFileSync(src));
        }
      }catch(e){
        self.log("Copy File : "+src+" to "+dest+" error");
      }
      */
    }

    this.systemUpdate = function(update_folder,platform){
        self.log("Updating the system .... : "+platform);
        if(!self.systemIsUpdating){
            self.systemIsUpdating = true;
            self.deleteFile("app_backup",function(){
                    try{
                        self.makeDir("files_backup",function(){
                            self.moveFile(self.ROUTES['MAIN_JS'].path,"files_backup/"+self.ROUTES['MAIN_JS'].path,function(ok,file_ref){
                              self.log("Moving "+file_ref+" ok? "+ok);
                                self.moveFile(self.ROUTES['MAIN_HTML'].path,"files_backup/"+self.ROUTES['MAIN_HTML'].path,function(ok,file_ref){
                                  self.log("Moving "+file_ref+" ok? "+ok);
                                    self.moveFile(self.ROUTES['VER'].path,"files_backup/"+self.ROUTES['VER'].path,function(ok,file_ref){
                                      self.log("Moving "+file_ref+" ok? "+ok);
                                        self.moveFile("app/","app_backup/",function(ok,file_ref){
                                          self.log("Moving "+file_ref+" ok? "+ok);
                                            try{
                                                self.moveFile(update_folder+"files/app/","app.new/",function(ok,file_ref){
                                                    self.log("Moving "+file_ref+" ok? "+ok);
                                                    self.moveFile(update_folder+"files/"+self.ROUTES['MAIN_JS'].path,"./"+self.ROUTES['MAIN_JS'].path+".new",function(ok,file_ref){
                                                      self.log("Moving "+file_ref+" ok? "+ok);
                                                      self.moveFile(update_folder+"files/"+self.ROUTES['MAIN_HTML'].path,"./"+self.ROUTES['MAIN_HTML'].path+".new",function(ok,file_ref){
                                                        self.log("Moving "+file_ref+" ok? "+ok);
                                                        self.moveFile(update_folder+"files/"+self.ROUTES['VER'].path,"./"+self.ROUTES['VER'].path+".new",function(ok,file_ref){
                                                          self.log("Moving "+file_ref+" ok? "+ok);
                                                          self.deleteFile(update_folder,function(ok,file_ref){
                                                            self.log("Deleting "+file_ref+" ok? "+ok);
                                                            setTimeout(function(){
                                                              self.rebootSystem();
                                                            },3000);
                                                          });
                                                          
                                                        });
                                                        
                                                      });
                                                      
                                                      
                                                    });
                                                    
                                                });
                                            }
                                            catch(e){
                                                self.log(JSON.stringify(e));
                                                self.moveFile("app_backup/", "app/",function(){})
                                                self.moveFile("files_backup/"+self.ROUTES['MAIN_JS'].path, self.ROUTES['MAIN_JS'].path,function(){})
                                                self.moveFile("files_backup/"+self.ROUTES['MAIN_HTML'].path, self.ROUTES['MAIN_HTML'].path,function(){})
                                                self.moveFile("files_backup/"+self.ROUTES['VER'].path, self.ROUTES['VER'].path,function(){})
                                                setTimeout(function(){
                                                  self.rebootSystem();
                                                },3000);

                                            }
                                        });
                                    })
                                })
                            })
                        })
                    }catch(e){
                        self.log(JSON.stringify(e));
                        try{
                            self.moveFile("app/","app_backup/",function(){
                                self.moveFile(update_folder+"files/app/","app/",function(){
                                    self.moveFile(update_folder+"files/"+self.ROUTES['MAIN_JS'].path,self.ROUTES['MAIN_JS'].path);
                                    self.moveFile(update_folder+"files/"+self.ROUTES['MAIN_HTML'].path,self.ROUTES['MAIN_HTML'].path);
                                    self.moveFile(update_folder+"files/"+self.ROUTES['VER'].path,self.ROUTES['VER'].path);
                                    self.deleteFile(update_folder);
                                    setTimeout(function(){
                                      self.rebootSystem();
                                    },3000);

                                });
                            });
                        }
                        catch(ee){
                            self.log(JSON.stringify(ee));
                            try{
                                self.moveFile("files_backup/"+self.ROUTES['MAIN_JS'].path, self.ROUTES['MAIN_JS'].path,function(){})
                                self.moveFile("files_backup/"+self.ROUTES['MAIN_HTML'].path, self.ROUTES['MAIN_HTML'].path, function(){})
                                self.moveFile("files_backup/"+self.ROUTES['VER'].path, self.ROUTES['VER'].path, function(){})
                                setTimeout(function(){
                                  self.rebootSystem();
                                },3000);

                            }
                            catch(eee){
                                self.log(JSON.stringify(eee));
                                setTimeout(function(){
                                  self.rebootSystem();
                                },3000);
                            }
                        }
                    }
            });
            self.systemIsUpdating = false;
        }
    };

    this.systemRepairUpdate = function(){
      // TODO
    };

    this.takeScreenshot = function(callback,params){
      self.nodejs_service.emit("request",{'command':'takeScreenshot','callback':true,'params':params},function(base64,params){
        try{
          var img = new Image();
          img.crossOrigin = 'Anonymous';
          img.onload = function(){
              var base64 = false;
              var canvas = document.createElement('CANVAS');
              var context = canvas.getContext('2d');
              //250x140 Screenshot size
              var width = 250;
              var height = 140;
              if (img.height > img.width){
                  width = 140;
                  height = 250;
              }
              canvas.height = height;
              canvas.width = width;
              context.drawImage(img, 0, 0,width,height);
              base64 = canvas.toDataURL("image/jpeg", params);
              if(typeof(callback) !== "undefined"){
                  self.screenshotServer = base64.substring(23);
                  callback(base64.substring(23),params);
              }
              canvas = null;
          };
          var d = new Date();
          img.src = self.rootDir+"capture.jpg?time="+d;
        }catch(e){
          self.debug("Screenshot Exception");
        }
        
      });
    };

    this.getScreenshot = function(callback){
      self.nodejs_service.emit("request",{'command':'takeScreenshot','callback':true},function(base64){
        try{
          var img = new Image();
          img.crossOrigin = 'Anonymous';
          img.onload = function(){
              var base64 = false;
              var canvas = document.createElement('CANVAS');
              var context = canvas.getContext('2d');
              //250x140 Screenshot size
              var width = 250;
              var height = 140;
              if (img.height > img.width){
                  width = 140;
                  height = 250;
              }
              canvas.height = height;
              canvas.width = width;
              context.drawImage(img, 0, 0,width,height);
              base64 = canvas.toDataURL("image/jpeg", params);
              if(typeof(callback) !== "undefined"){
                  self.screenshotServer = base64.substring(23);
                  callback(base64.substring(23),params);
              }
              canvas = null;
          };
          var d = new Date();
          img.src = self.rootDir+"capture.jpg?time="+d;
        }catch(e){
          self.debug("Screenshot Exception");
        }
      });
    };

    this.getMousePos = function(){
      var pos = false;
      return pos;
    };

    this.setSystemDateTime = function(timestamp,callback,params){
        // TODO
    };

    this.rebootSystem = function(platform){
      self.nodejs_service.emit("request",{'command':'rebootSystem','platform':platform});
    };

    this.haltSystem = function(platform){
        
    };

    this.internetConnected = function() {
        return true;
    };

    this.getNetworkInfo = function(callback,params){
      self.nodejs_service.emit("request",{'command':'getNetworkInfo','callback':true,'params':params},function(network_info,params){
        self.network_info = network_info;
        if(typeof(callback) !== "undefined"){
            callback(network_info,params);
        }
      });
      return self.network_info;
    };


    this.getScreenSize = function(){
        return {'width':1920,'height':1080};
    };

    this.setMaxWindowDesktop = function(screen){
      
    };

    this.getProxyForURL = function(url){
    
    };

    this.setProxyConfig = function(config){

    };

    this.getAddWhiteList = function(srcOrigin, destProtocol, destHost, allowDestinationSubdomains){
    };

    this.getRemoveWhiteList = function(srcOrigin, destProtocol, destHost, allowDestinationSubdomains){
    };

    this.getDataPath = function(){
    };

    this.setCrashDumpPath = function(folderPath){
    };

    this.clearCache = function(){
    };

    this.quit = function(){
    };

    this.reload = function(platform){

    };

    this.recover = function(){

    };

    this.vanish = function(){

    };

    this.setWindow = function(x,y,w,h){
    };

    this.alwaysOnTop = function(value){

    };

    this.focusWindow = function(){

    };

    this.disableRemoteControl = function(platform){
        self.deactivateControl();
        self.notifyError(self.ERROR['OPERATING_SYSTEM_CONTROLLER']+8,self.name+": Disable remote control on platform : "+platform);

    };

    this.enableRemoteControl = function(platform,tunnels){
        self.activateControl();
        self.notifyError(self.ERROR['OPERATING_SYSTEM_CONTROLLER']+8,self.name+": Enable remote control on platform : "+platform);
        
    };

    this.keepAwake = function(platform){
        
    };

    this.activateControl = function(){
      self.debug = true;
      self.SocketConnector.createSocket();
    };
    this.deactivateControl = function(){
      self.debug = false;
      self.SocketConnector.disconnectSocket();
    };
    this.sendControlLog = function(ori, name, text){
        if(typeof(self.SocketConnector) !== "undefined"){
          self.SocketConnector.logsSocket(ori, (new Date()).toTimeString().split(' ')[0] +" .. " + name+ "--"+text);
        }
    };
    this.changeCore = function(id){
        self.SocketConnector.changeCore(id);
    };
    this.saveIdContent = function(idContent){
        self.id_content_now = idContent;
    };
    this.get_tunnels_params = function(){
        self.api_connector.get(self.api_url,self.api_ver,"player/get_tunnels_params/id",self.core_id,self.remoteResponse);
    };
    this.getInfoSystem = function(){

    };


    // NOT IN USE
    this.socketServerClose = function(uuid,error_code,reason){
        // EXAMPLE
        // wsserver.close({'uuid':'8e176b14-a1af-70a7-3e3d-8b341977a16e'}, 4000, 'my reason');

    };

    this.socketServerStop = function(){
        if(self.webwebsocket_server){
            self.websocket_server.close();
            self.websocket_active = false;
        }
    };

    this.socketServerSend = function(conn,msg){
        // TODO
    };

    this.socketServerBroadcast = function(msg){
      self.nodejs_service.emit("request",{'command':'socketServerBroadcast','msg':msg});
    };

    this.socketServerStart = function(port,onOpenCallback,onMessageCallback,onTerminatedCallback){
      if(!self.websocket_server){
        self.websocket_server = true;
        if(typeof(port) !== "undefined"){self.websocket_port = port;}
        if(typeof(onOpenCallback) !== "undefined"){
          self.websocket_onOpenCallback = onOpenCallback;
        }
        if(typeof(onMessageCallback) !== "undefined"){
         self.websocket_onMessageCallback = onMessageCallback;
        }
        if(typeof(onTerminatedCallback) !== "undefined"){
         self.websocket_onTerminatedCallback = onTerminatedCallback;
        }
        self.nodejs_service.on('onOpenCallback',function(){
          self.websocket_onOpenCallback();
        });
        self.nodejs_service.on('onMessageCallback',function(msg){
          self.websocket_onMessageCallback(msg);
        });
        self.nodejs_service.on('onTerminatedCallback',function(){
          self.websocket_onTerminatedCallback();
        });
        
        self.nodejs_service.emit("request",{'command':'socketServerStart','port':port});
      }
      
    };

    this.onSocketFailure = function(error){
        // bright-node.js
    };

    this.onSocketOpen = function(conn){
      // bright-node.js
    };

    this.onSocketMessage = function(msg){
      // bright-node.js
    };

    this.onSocketClose = function(conn){
        // bright-node.js
    };

    this.onSocketError = function(conn){
        // bright-node.js
    };

    this.onSocketStart = function(addr, port){
        // bright-node.js
    };

    this.onSocketStartFail = function(reason){
      // bright-node.js
    };

    this.onSocketStop = function(addr, port){
        // bright-node.js
    };

    this.onSocketStopFail = function(reason){
        // bright-node.js
    };

    this.setContentRotation = function(options, callback_setContentRotation) {
    }

    this.getDisplayOrientation = function(callback,params) {

    }

    this.getLIC = function(callback){
      self.readFile("admira.lic", function(resultR, file){
        if(resultR){
          callback("admira.lic = "+resultR);
        }
        else{
          callback("error read admira.lic");
        }
      });
    }
    this.createLIC = function(data, callback){

      callback("no function");
    }
    this.deleteAll = function(callback){
      self.deleteFile("content/",function(result){
        self.deleteFile("xmls/",function(result){
          self.deleteFile("log/",function(result){
            self.deleteFile("core.xml",function(result){
              self.deleteFile("week.tstamp",function(result){
                setTimeout(function(){
                  self.rebootSystem();
                },2000);
                if(err){
                  callback(JSON.stringify(err));
                }else{
                  callback(result);
                }
              });
            });
          });
        });
      });
    };

    this.deleteAllAll = function(callback){
      callback("no function");
    };
    this.getInfoSystemPlus = function(callback){
      callback("no function");
    };
    this.getTimers = function(callback){
      callback("no function");
    };
    this.clearCache = function(callback) {
      callback("no function");
    };
    this.calculateReboot = function(callback) {
      callback("no function");
    };
    this.copyUSB = function (callback){
      callback("no function");
    };
    this.deleteAll2 =  function(callback){
      callback("no function");
    };
    this.upgradeApplication = function (callback_upgradeApplication){
      callback_upgradeApplication("no function");
    };
    this.upgradeApplicationInsert = function(url, callback_upgradeApplicationInsert){
      callback_upgradeApplicationInsert("no function");
    }
    this.upgradeApplicationInstall = function(callback_upgradeApplicationInstall){
        callback_upgradeApplicationInstall("no function");
    }
    this.upgradeApplicationNow = function(callback_upgradeApplicationNow){
        callback_upgradeApplicationNow("no function");
    }
    this.updateApplicationS = function(callback_updateApplicationS){
        callback_updateApplicationS("no function");
    }


    this.screenControllersRelation = {
        7: 'PANASONIC_RS232',
        //8	: 'LG_RS232',
        11: 'ALBIRAL_RS232',          // Digiview
        15: 'RLY8_RS232',
        27: 'PHILIPS_RS232',
        56: 'PCB_RS232',
        62: 'LG_IMPACT_RS232' ,
        44: 'SAMSUNG_RJ45' ,
        64: 'DYNASCAN_RS232' ,
        24: 'SAMSUNG_RS232' ,
        55: 'EPSON_RS232',
        61: 'LG_WINDOWS_HDMI',
        00: ''
    };


    this.generateNewScreenController = function ( screenData, exceptionList, counter){
        
    }

    this.updateFirmware = function(data, callback_updateFirmware){
      callback_updateFirmware("no function");
    };
    this.getStatusPanel = function(url, callback_getStatusPanel){
      callback_getStatusPanel("no function");
    };
    this.setPanelOff = function(url, callback_setPanelOff){
      if(typeof(callback_setPanelOff) != "undefined"){
        callback_setPanelOff("Panel Off by suspend system android");
      }
    };
    this.setPanelOn = function(url, callback_setPanelOn){
      if(typeof(callback_setPanelOn) != "undefined"){
        callback_setPanelOn("no function");
      }
    };
    this.changePictureMode = function(callback_changePictureMode){
        callback_changePictureMode("no function");
    }
    this.getPictureProperty = function(callback_getPictureProperty){
        callback_getPictureProperty("no function");
    }
    this.setPortraitMode = function(data, callback_setPortraitMode){
        callback_setPortraitMode("no function");
    }
    this.getContentRotation = function(callback_getContentRotation){
        callback_getContentRotation("no function");
    }
    this.setContentRotation = function(data, callback_setContentRotation){
        callback_setContentRotation("no function");
    }
    this.getVideoStatus = function(callback_getVideoStatus){
        callback_getVideoStatus("no function");
    }
    this.shellExec = function(command,callback,params){
      var result = "";
      if(typeof(callback) !== "undefined"){
          callback(result,command,params);
      }
    };

    this.findSyncIp = function (callback){
      self.nodejs_service.emit("request",{'command':'findSyncIp','callback':true},function(network_info,params){
        if(typeof(callback) !== "undefined"){
            callback(network_info,params);
        }
      });
    };
    this.getPowerOnOffHistory = function(callback_getPowerOnOffHistory){
        callback_getPowerOnOffHistory("no function");
    }
    this.getBrigthness = function(callback_getBrigthness){
        callback_getBrigthness("no function");
    }
    this.setBrightness = function(brightness, callback_setBrightness){
        callback_setBrightness("no function");
    }
    this.getContrast = function(callback_getContrast){
        callback_getContrast("no function");
    }
    this.setContrast = function(contrast, callback_setContrast){
        callback_setContrast("no function");
    }
    this.getBacklight = function(callback_getBacklight){
        callback_getBacklight("no function");
    }
    this.setBacklight = function(backlight, callback_setBacklight){
        callback_setBacklight("no function");
    }
    this.geConfigPanel = function(callback_geConfigPanel){
        callback_geConfigPanel("no function");
    }
    this.setConfigPanel = function(data, callback_setConfigPanel){
        callback_setConfigPanel("no function");
    }
    this.setNativePortraitMode = function(data, mode, callback_setNativePortraitMode){
        callback_setNativePortraitMode("no function");
    }
    this.getStatusRemoteControl = function(callback_getStatusRemoteControl){
      callback_getStatusRemoteControl("no function")
    }
    this.setStatusRemoteControl = function(data, callback_setStatusRemoteControl){
        callback_setStatusRemoteControl("no function");
    }
    
    
}
BrightSystemController.prototype = new SystemController();
