function ConditionalService(){
    if(arguments.callee._singletonInstance){
	    return arguments.callee._singletonInstance;
	}
	arguments.callee._singletonInstance = this;
    
	var self = this; self.name = "ConditionalService"; // MANDATORY
    
    this.interval = 300; // Check modification date for selected files
    this.timer = 0;
    this.files = [];
    this.xml_parser = new DOMParser();
    
    this.internet_status = false;
    this.internet_recheck_counter = -1;
    this.first_run = true;
    
    this.init = function(callback){
        self.sendCondition = callback;
        if(self.timer == 0){
            self.timer = setTimeout(self.watch,self.interval);
        }
    };
    
    this.unload = function(){
        clearTimeout(self.timer);
        self.sendCondition = null;
        self.files = null;
        self.xml_parser = null;
    };
    
    this.update = function(types){
        if(typeof(types) !== "undefined"){
            self.files = types;
        }
        self.first_run = true;
        // If internet condition found ... check internet connectivity for condition file write 
        var index = index = self.files.map(function(e){return e.filename;}).indexOf("internet_connected.xml");
        if(index >= 0){
            self.internet_recheck_counter = 0;
        }else{
            self.internet_recheck_counter = -1;
        }
    };
    
    this.watch = function(){
        clearTimeout(self.timer);
        if(self.internet_recheck_counter > 5){ // Check internet every 1s
            self.internet_recheck_counter = 0;
            self.internetCheck();
        }else if(self.internet_recheck_counter >= 0){
            self.internet_recheck_counter++;
        }
        if(self.files.length > 0){
            self.OS.watchDirectory(self.ROUTES['CONDITION'].path,self.files,self.onConditionFileChange);
        }else{
            self.timer = setTimeout(self.watch,self.interval);
        }
    };
    
    this.onConditionFileChange = function(files,changed){
        self.files = null;
        self.files = files;
        for(var i=0;i<changed.length;i++){
            if(changed[i].mdate > 0){
                self.OS.readFile(self.ROUTES['CONDITION'].path+changed[i].filename,function(data,file_ref){
                    try{
                        var filename = file_ref.substring(file_ref.lastIndexOf('/')+1,file_ref.length);
                        var xmlDoc=self.xml_parser.parseFromString(data,"text/xml");
                        var condition = {
                            'id': xmlDoc.getElementsByTagName("condition")[0].getAttribute('id'),
                            'filename':filename,
                            'tstamp':parseInt(xmlDoc.getElementsByTagName("condition")[0].getAttribute('tstamp')),
                            'version':xmlDoc.getElementsByTagName("condition")[0].getAttribute('version'),
                            'status':xmlDoc.getElementsByTagName("condition")[0].getAttribute('status'),
                            'value':xmlDoc.getElementsByTagName("value")[0].childNodes[0].nodeValue,
                            'broadcast':false
                        };
                        if(self.first_run){
                          self.first_run = false;
                        }else{
                          if(typeof(self.sendCondition) !== "undefined"){
                              self.sendCondition(condition);
                          }
                        }
                    }catch(e){
                        self.notifyError(self.ERROR['CONDITIONAL_SERVICE']+1,self.name+": Function onConditionFileChange() error : can not read condition file "+filename+" : "+e.toString());
                    }
                });
            }else{
                self.notifyError(self.ERROR['CONDITIONAL_SERVICE']+1,self.name+": Function onConditionFileChange() warning : condition file : "+changed[i].filename+" deleted.");
            }
        }
        self.timer = setTimeout(self.watch,self.interval);
    };
    
    this.writeConditionFile = function(condition){
        try{
            if(typeof(condition) !== "undefined"){
                var xml = '<?xml version="1.0" encoding="UTF-8"?>';
                xml += '<condition id="'+condition.id+'" ';
                xml += 'tstamp="'+condition.tstamp+'" ';
                xml += 'version="'+condition.version+'" ';
                xml += 'status="'+condition.status+'">';
                xml += '<value>'+condition.value+'</value>';
                xml += '<info> --- </info></condition>';
                self.OS.writeFile(self.ROUTES['CONDITION'].path+condition.filename,xml);
            }
        }catch(e){
             self.notifyError(self.ERROR['CONDITIONAL_SERVICE']+2,self.name+": Function writeConditionFile() error : can not write condition file ... ");
        }
    };
    
    this.internetCheck = function(){
        
        var internet = 0;
        
        if(self.internet_status != self.OS.internetConnected()){
            var timestamp = parseInt(self.getDate().getTime()/1000);
            self.internet_status = !self.internet_status;
            if(self.internet_status){
                internet = 1;
            }else{
                internet = 0;
            }
            var condition = {
                'id': "27",
                'filename': "internet_connected.xml",
                'mdate': 0,
                'tstamp': timestamp,
                'version': "1.0",
                'status': "ok",
                'value': internet
            };
            self.writeConditionFile(condition);
        }
    };
}
ConditionalService.prototype = new BasicService();
